@@ -1,6 +1,6 @@
-#![allow(unused_variables, non_upper_case_globals, non_snake_case, unused_unsafe, non_camel_case_types, dead_code, clippy::all)]
-#[derive(:: core :: clone :: Clone, :: core :: marker :: Copy)]
+#![allow(non_snake_case, non_camel_case_types, non_upper_case_globals, clashing_extern_declarations, clippy::all)]
 #[repr(C)]
+#[doc = "*Required features: 'Foundation_Numerics'*"]
 pub struct Matrix3x2 {
     pub M11: f32,
     pub M12: f32,
@@ -9,23 +9,17 @@ pub struct Matrix3x2 {
     pub M31: f32,
     pub M32: f32,
 }
-impl Matrix3x2 {}
-impl ::core::default::Default for Matrix3x2 {
-    fn default() -> Self {
-        unsafe { ::core::mem::zeroed() }
+impl ::core::marker::Copy for Matrix3x2 {}
+impl ::core::clone::Clone for Matrix3x2 {
+    fn clone(&self) -> Self {
+        *self
     }
 }
 impl ::core::fmt::Debug for Matrix3x2 {
-    fn fmt(&self, fmt: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
-        fmt.debug_struct("Matrix3x2").field("M11", &self.M11).field("M12", &self.M12).field("M21", &self.M21).field("M22", &self.M22).field("M31", &self.M31).field("M32", &self.M32).finish()
+    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
+        f.debug_struct("Matrix3x2").field("M11", &self.M11).field("M12", &self.M12).field("M21", &self.M21).field("M22", &self.M22).field("M31", &self.M31).field("M32", &self.M32).finish()
     }
 }
-impl ::core::cmp::PartialEq for Matrix3x2 {
-    fn eq(&self, other: &Self) -> bool {
-        self.M11 == other.M11 && self.M12 == other.M12 && self.M21 == other.M21 && self.M22 == other.M22 && self.M31 == other.M31 && self.M32 == other.M32
-    }
-}
-impl ::core::cmp::Eq for Matrix3x2 {}
 unsafe impl ::windows::core::Abi for Matrix3x2 {
     type Abi = Self;
 }
@@ -35,6 +29,17 @@ unsafe impl ::windows::core::RuntimeType for Matrix3x2 {
 impl ::windows::core::DefaultType for Matrix3x2 {
     type DefaultType = Self;
 }
+impl ::core::cmp::PartialEq for Matrix3x2 {
+    fn eq(&self, other: &Self) -> bool {
+        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<Matrix3x2>()) == 0 }
+    }
+}
+impl ::core::cmp::Eq for Matrix3x2 {}
+impl ::core::default::Default for Matrix3x2 {
+    fn default() -> Self {
+        unsafe { ::core::mem::zeroed() }
+    }
+}
 impl Matrix3x2 {
     pub fn identity() -> Self {
         Self { M11: 1.0, M12: 0.0, M21: 0.0, M22: 1.0, M31: 0.0, M32: 0.0 }
@@ -89,14 +94,7 @@ impl Matrix3x2 {
         }
     }
     fn impl_mul_f32(&self, rhs: f32) -> Self {
-        Self {
-            M11: self.M11 * rhs,
-            M12: self.M12 * rhs,
-            M21: self.M21 * rhs,
-            M22: self.M22 * rhs,
-            M31: self.M31 * rhs,
-            M32: self.M32 * rhs,
-        }
+        Self { M11: self.M11 * rhs, M12: self.M12 * rhs, M21: self.M21 * rhs, M22: self.M22 * rhs, M31: self.M31 * rhs, M32: self.M32 * rhs }
     }
 }
 impl ::core::ops::Add<Matrix3x2> for Matrix3x2 {
@@ -183,8 +181,8 @@ impl ::core::ops::Mul<f32> for &Matrix3x2 {
         self.impl_mul_f32(rhs)
     }
 }
-#[derive(:: core :: clone :: Clone, :: core :: marker :: Copy)]
 #[repr(C)]
+#[doc = "*Required features: 'Foundation_Numerics'*"]
 pub struct Matrix4x4 {
     pub M11: f32,
     pub M12: f32,
@@ -203,40 +201,17 @@ pub struct Matrix4x4 {
     pub M43: f32,
     pub M44: f32,
 }
-impl Matrix4x4 {}
-impl ::core::default::Default for Matrix4x4 {
-    fn default() -> Self {
-        unsafe { ::core::mem::zeroed() }
+impl ::core::marker::Copy for Matrix4x4 {}
+impl ::core::clone::Clone for Matrix4x4 {
+    fn clone(&self) -> Self {
+        *self
     }
 }
 impl ::core::fmt::Debug for Matrix4x4 {
-    fn fmt(&self, fmt: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
-        fmt.debug_struct("Matrix4x4")
-            .field("M11", &self.M11)
-            .field("M12", &self.M12)
-            .field("M13", &self.M13)
-            .field("M14", &self.M14)
-            .field("M21", &self.M21)
-            .field("M22", &self.M22)
-            .field("M23", &self.M23)
-            .field("M24", &self.M24)
-            .field("M31", &self.M31)
-            .field("M32", &self.M32)
-            .field("M33", &self.M33)
-            .field("M34", &self.M34)
-            .field("M41", &self.M41)
-            .field("M42", &self.M42)
-            .field("M43", &self.M43)
-            .field("M44", &self.M44)
-            .finish()
+    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
+        f.debug_struct("Matrix4x4").field("M11", &self.M11).field("M12", &self.M12).field("M13", &self.M13).field("M14", &self.M14).field("M21", &self.M21).field("M22", &self.M22).field("M23", &self.M23).field("M24", &self.M24).field("M31", &self.M31).field("M32", &self.M32).field("M33", &self.M33).field("M34", &self.M34).field("M41", &self.M41).field("M42", &self.M42).field("M43", &self.M43).field("M44", &self.M44).finish()
     }
 }
-impl ::core::cmp::PartialEq for Matrix4x4 {
-    fn eq(&self, other: &Self) -> bool {
-        self.M11 == other.M11 && self.M12 == other.M12 && self.M13 == other.M13 && self.M14 == other.M14 && self.M21 == other.M21 && self.M22 == other.M22 && self.M23 == other.M23 && self.M24 == other.M24 && self.M31 == other.M31 && self.M32 == other.M32 && self.M33 == other.M33 && self.M34 == other.M34 && self.M41 == other.M41 && self.M42 == other.M42 && self.M43 == other.M43 && self.M44 == other.M44
-    }
-}
-impl ::core::cmp::Eq for Matrix4x4 {}
 unsafe impl ::windows::core::Abi for Matrix4x4 {
     type Abi = Self;
 }
@@ -246,6 +221,17 @@ unsafe impl ::windows::core::RuntimeType for Matrix4x4 {
 impl ::windows::core::DefaultType for Matrix4x4 {
     type DefaultType = Self;
 }
+impl ::core::cmp::PartialEq for Matrix4x4 {
+    fn eq(&self, other: &Self) -> bool {
+        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<Matrix4x4>()) == 0 }
+    }
+}
+impl ::core::cmp::Eq for Matrix4x4 {}
+impl ::core::default::Default for Matrix4x4 {
+    fn default() -> Self {
+        unsafe { ::core::mem::zeroed() }
+    }
+}
 impl Matrix4x4 {
     fn impl_add(&self, rhs: &Self) -> Self {
         Self {
@@ -412,29 +398,23 @@ impl ::core::ops::Mul<f32> for &Matrix4x4 {
         self.impl_mul_f32(rhs)
     }
 }
-#[derive(:: core :: clone :: Clone, :: core :: marker :: Copy)]
 #[repr(C)]
+#[doc = "*Required features: 'Foundation_Numerics'*"]
 pub struct Plane {
     pub Normal: Vector3,
     pub D: f32,
 }
-impl Plane {}
-impl ::core::default::Default for Plane {
-    fn default() -> Self {
-        unsafe { ::core::mem::zeroed() }
+impl ::core::marker::Copy for Plane {}
+impl ::core::clone::Clone for Plane {
+    fn clone(&self) -> Self {
+        *self
     }
 }
 impl ::core::fmt::Debug for Plane {
-    fn fmt(&self, fmt: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
-        fmt.debug_struct("Plane").field("Normal", &self.Normal).field("D", &self.D).finish()
+    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
+        f.debug_struct("Plane").field("Normal", &self.Normal).field("D", &self.D).finish()
     }
 }
-impl ::core::cmp::PartialEq for Plane {
-    fn eq(&self, other: &Self) -> bool {
-        self.Normal == other.Normal && self.D == other.D
-    }
-}
-impl ::core::cmp::Eq for Plane {}
 unsafe impl ::windows::core::Abi for Plane {
     type Abi = Self;
 }
@@ -444,31 +424,36 @@ unsafe impl ::windows::core::RuntimeType for Plane {
 impl ::windows::core::DefaultType for Plane {
     type DefaultType = Self;
 }
-#[derive(:: core :: clone :: Clone, :: core :: marker :: Copy)]
+impl ::core::cmp::PartialEq for Plane {
+    fn eq(&self, other: &Self) -> bool {
+        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<Plane>()) == 0 }
+    }
+}
+impl ::core::cmp::Eq for Plane {}
+impl ::core::default::Default for Plane {
+    fn default() -> Self {
+        unsafe { ::core::mem::zeroed() }
+    }
+}
 #[repr(C)]
+#[doc = "*Required features: 'Foundation_Numerics'*"]
 pub struct Quaternion {
     pub X: f32,
     pub Y: f32,
     pub Z: f32,
     pub W: f32,
 }
-impl Quaternion {}
-impl ::core::default::Default for Quaternion {
-    fn default() -> Self {
-        unsafe { ::core::mem::zeroed() }
+impl ::core::marker::Copy for Quaternion {}
+impl ::core::clone::Clone for Quaternion {
+    fn clone(&self) -> Self {
+        *self
     }
 }
 impl ::core::fmt::Debug for Quaternion {
-    fn fmt(&self, fmt: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
-        fmt.debug_struct("Quaternion").field("X", &self.X).field("Y", &self.Y).field("Z", &self.Z).field("W", &self.W).finish()
+    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
+        f.debug_struct("Quaternion").field("X", &self.X).field("Y", &self.Y).field("Z", &self.Z).field("W", &self.W).finish()
     }
 }
-impl ::core::cmp::PartialEq for Quaternion {
-    fn eq(&self, other: &Self) -> bool {
-        self.X == other.X && self.Y == other.Y && self.Z == other.Z && self.W == other.W
-    }
-}
-impl ::core::cmp::Eq for Quaternion {}
 unsafe impl ::windows::core::Abi for Quaternion {
     type Abi = Self;
 }
@@ -478,29 +463,34 @@ unsafe impl ::windows::core::RuntimeType for Quaternion {
 impl ::windows::core::DefaultType for Quaternion {
     type DefaultType = Self;
 }
-#[derive(:: core :: clone :: Clone, :: core :: marker :: Copy)]
-#[repr(C)]
-pub struct Rational {
-    pub Numerator: u32,
-    pub Denominator: u32,
+impl ::core::cmp::PartialEq for Quaternion {
+    fn eq(&self, other: &Self) -> bool {
+        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<Quaternion>()) == 0 }
+    }
 }
-impl Rational {}
-impl ::core::default::Default for Rational {
+impl ::core::cmp::Eq for Quaternion {}
+impl ::core::default::Default for Quaternion {
     fn default() -> Self {
         unsafe { ::core::mem::zeroed() }
     }
 }
+#[repr(C)]
+#[doc = "*Required features: 'Foundation_Numerics'*"]
+pub struct Rational {
+    pub Numerator: u32,
+    pub Denominator: u32,
+}
+impl ::core::marker::Copy for Rational {}
+impl ::core::clone::Clone for Rational {
+    fn clone(&self) -> Self {
+        *self
+    }
+}
 impl ::core::fmt::Debug for Rational {
-    fn fmt(&self, fmt: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
-        fmt.debug_struct("Rational").field("Numerator", &self.Numerator).field("Denominator", &self.Denominator).finish()
+    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
+        f.debug_struct("Rational").field("Numerator", &self.Numerator).field("Denominator", &self.Denominator).finish()
     }
 }
-impl ::core::cmp::PartialEq for Rational {
-    fn eq(&self, other: &Self) -> bool {
-        self.Numerator == other.Numerator && self.Denominator == other.Denominator
-    }
-}
-impl ::core::cmp::Eq for Rational {}
 unsafe impl ::windows::core::Abi for Rational {
     type Abi = Self;
 }
@@ -510,29 +500,34 @@ unsafe impl ::windows::core::RuntimeType for Rational {
 impl ::windows::core::DefaultType for Rational {
     type DefaultType = Self;
 }
-#[derive(:: core :: clone :: Clone, :: core :: marker :: Copy)]
-#[repr(C)]
-pub struct Vector2 {
-    pub X: f32,
-    pub Y: f32,
+impl ::core::cmp::PartialEq for Rational {
+    fn eq(&self, other: &Self) -> bool {
+        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<Rational>()) == 0 }
+    }
 }
-impl Vector2 {}
-impl ::core::default::Default for Vector2 {
+impl ::core::cmp::Eq for Rational {}
+impl ::core::default::Default for Rational {
     fn default() -> Self {
         unsafe { ::core::mem::zeroed() }
     }
 }
+#[repr(C)]
+#[doc = "*Required features: 'Foundation_Numerics'*"]
+pub struct Vector2 {
+    pub X: f32,
+    pub Y: f32,
+}
+impl ::core::marker::Copy for Vector2 {}
+impl ::core::clone::Clone for Vector2 {
+    fn clone(&self) -> Self {
+        *self
+    }
+}
 impl ::core::fmt::Debug for Vector2 {
-    fn fmt(&self, fmt: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
-        fmt.debug_struct("Vector2").field("X", &self.X).field("Y", &self.Y).finish()
+    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
+        f.debug_struct("Vector2").field("X", &self.X).field("Y", &self.Y).finish()
     }
 }
-impl ::core::cmp::PartialEq for Vector2 {
-    fn eq(&self, other: &Self) -> bool {
-        self.X == other.X && self.Y == other.Y
-    }
-}
-impl ::core::cmp::Eq for Vector2 {}
 unsafe impl ::windows::core::Abi for Vector2 {
     type Abi = Self;
 }
@@ -542,6 +537,17 @@ unsafe impl ::windows::core::RuntimeType for Vector2 {
 impl ::windows::core::DefaultType for Vector2 {
     type DefaultType = Self;
 }
+impl ::core::cmp::PartialEq for Vector2 {
+    fn eq(&self, other: &Self) -> bool {
+        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<Vector2>()) == 0 }
+    }
+}
+impl ::core::cmp::Eq for Vector2 {}
+impl ::core::default::Default for Vector2 {
+    fn default() -> Self {
+        unsafe { ::core::mem::zeroed() }
+    }
+}
 impl Vector2 {
     pub fn new(X: f32, Y: f32) -> Self {
         Self { X, Y }
@@ -564,18 +570,15 @@ impl Vector2 {
     pub fn length_squared(&self) -> f32 {
         self.dot(self)
     }
-    #[cfg(feature = "std")]
     pub fn length(&self) -> f32 {
         self.length_squared().sqrt()
     }
-    #[cfg(feature = "std")]
     pub fn distance(&self, value: &Self) -> f32 {
         (self - value).length()
     }
     pub fn distance_squared(&self, value: &Self) -> f32 {
         (self - value).length_squared()
     }
-    #[cfg(feature = "std")]
     pub fn normalize(&self) -> Self {
         self / self.length()
     }
@@ -718,30 +721,24 @@ impl ::core::ops::Mul<f32> for &Vector2 {
         self.impl_mul_f32(rhs)
     }
 }
-#[derive(:: core :: clone :: Clone, :: core :: marker :: Copy)]
 #[repr(C)]
+#[doc = "*Required features: 'Foundation_Numerics'*"]
 pub struct Vector3 {
     pub X: f32,
     pub Y: f32,
     pub Z: f32,
 }
-impl Vector3 {}
-impl ::core::default::Default for Vector3 {
-    fn default() -> Self {
-        unsafe { ::core::mem::zeroed() }
+impl ::core::marker::Copy for Vector3 {}
+impl ::core::clone::Clone for Vector3 {
+    fn clone(&self) -> Self {
+        *self
     }
 }
 impl ::core::fmt::Debug for Vector3 {
-    fn fmt(&self, fmt: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
-        fmt.debug_struct("Vector3").field("X", &self.X).field("Y", &self.Y).field("Z", &self.Z).finish()
+    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
+        f.debug_struct("Vector3").field("X", &self.X).field("Y", &self.Y).field("Z", &self.Z).finish()
     }
 }
-impl ::core::cmp::PartialEq for Vector3 {
-    fn eq(&self, other: &Self) -> bool {
-        self.X == other.X && self.Y == other.Y && self.Z == other.Z
-    }
-}
-impl ::core::cmp::Eq for Vector3 {}
 unsafe impl ::windows::core::Abi for Vector3 {
     type Abi = Self;
 }
@@ -751,6 +748,17 @@ unsafe impl ::windows::core::RuntimeType for Vector3 {
 impl ::windows::core::DefaultType for Vector3 {
     type DefaultType = Self;
 }
+impl ::core::cmp::PartialEq for Vector3 {
+    fn eq(&self, other: &Self) -> bool {
+        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<Vector3>()) == 0 }
+    }
+}
+impl ::core::cmp::Eq for Vector3 {}
+impl ::core::default::Default for Vector3 {
+    fn default() -> Self {
+        unsafe { ::core::mem::zeroed() }
+    }
+}
 impl Vector3 {
     pub fn new(X: f32, Y: f32, Z: f32) -> Self {
         Self { X, Y, Z }
@@ -776,18 +784,15 @@ impl Vector3 {
     pub fn length_squared(&self) -> f32 {
         self.dot(self)
     }
-    #[cfg(feature = "std")]
     pub fn length(&self) -> f32 {
         self.length_squared().sqrt()
     }
-    #[cfg(feature = "std")]
     pub fn distance(&self, value: &Self) -> f32 {
         (self - value).length()
     }
     pub fn distance_squared(&self, value: &Self) -> f32 {
         (self - value).length_squared()
     }
-    #[cfg(feature = "std")]
     pub fn normalize(&self) -> Self {
         self / self.length()
     }
@@ -930,31 +935,25 @@ impl ::core::ops::Mul<f32> for &Vector3 {
         self.impl_mul_f32(rhs)
     }
 }
-#[derive(:: core :: clone :: Clone, :: core :: marker :: Copy)]
 #[repr(C)]
+#[doc = "*Required features: 'Foundation_Numerics'*"]
 pub struct Vector4 {
     pub X: f32,
     pub Y: f32,
     pub Z: f32,
     pub W: f32,
 }
-impl Vector4 {}
-impl ::core::default::Default for Vector4 {
-    fn default() -> Self {
-        unsafe { ::core::mem::zeroed() }
+impl ::core::marker::Copy for Vector4 {}
+impl ::core::clone::Clone for Vector4 {
+    fn clone(&self) -> Self {
+        *self
     }
 }
 impl ::core::fmt::Debug for Vector4 {
-    fn fmt(&self, fmt: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
-        fmt.debug_struct("Vector4").field("X", &self.X).field("Y", &self.Y).field("Z", &self.Z).field("W", &self.W).finish()
+    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
+        f.debug_struct("Vector4").field("X", &self.X).field("Y", &self.Y).field("Z", &self.Z).field("W", &self.W).finish()
     }
 }
-impl ::core::cmp::PartialEq for Vector4 {
-    fn eq(&self, other: &Self) -> bool {
-        self.X == other.X && self.Y == other.Y && self.Z == other.Z && self.W == other.W
-    }
-}
-impl ::core::cmp::Eq for Vector4 {}
 unsafe impl ::windows::core::Abi for Vector4 {
     type Abi = Self;
 }
@@ -964,6 +963,17 @@ unsafe impl ::windows::core::RuntimeType for Vector4 {
 impl ::windows::core::DefaultType for Vector4 {
     type DefaultType = Self;
 }
+impl ::core::cmp::PartialEq for Vector4 {
+    fn eq(&self, other: &Self) -> bool {
+        unsafe { ::windows::core::memcmp(self as *const _ as _, other as *const _ as _, core::mem::size_of::<Vector4>()) == 0 }
+    }
+}
+impl ::core::cmp::Eq for Vector4 {}
+impl ::core::default::Default for Vector4 {
+    fn default() -> Self {
+        unsafe { ::core::mem::zeroed() }
+    }
+}
 impl Vector4 {
     pub fn new(X: f32, Y: f32, Z: f32, W: f32) -> Self {
         Self { X, Y, Z, W }
@@ -992,18 +1002,15 @@ impl Vector4 {
     pub fn length_squared(&self) -> f32 {
         self.dot(self)
     }
-    #[cfg(feature = "std")]
     pub fn length(&self) -> f32 {
         self.length_squared().sqrt()
     }
-    #[cfg(feature = "std")]
     pub fn distance(&self, value: &Self) -> f32 {
         (self - value).length()
     }
     pub fn distance_squared(&self, value: &Self) -> f32 {
         (self - value).length_squared()
     }
-    #[cfg(feature = "std")]
     pub fn normalize(&self) -> Self {
         self / self.length()
     }
