@@ -1,8 +1,13 @@
-#![allow(unused_variables, non_upper_case_globals, non_snake_case, unused_unsafe, non_camel_case_types, dead_code, clippy::all)]
+#![allow(non_snake_case, non_camel_case_types, non_upper_case_globals, clashing_extern_declarations, clippy::all)]
+#[doc = "*Required features: 'Win32_Devices_SerialCommunication'*"]
 pub const CDB_REPORT_BITS: u32 = 0u32;
+#[doc = "*Required features: 'Win32_Devices_SerialCommunication'*"]
 pub const CDB_REPORT_BYTES: u32 = 1u32;
+#[doc = "*Required features: 'Win32_Devices_SerialCommunication'*"]
 pub const COMDB_MAX_PORTS_ARBITRATED: u32 = 4096u32;
+#[doc = "*Required features: 'Win32_Devices_SerialCommunication'*"]
 pub const COMDB_MIN_PORTS_ARBITRATED: u32 = 256u32;
+#[doc = "*Required features: 'Win32_Devices_SerialCommunication'*"]
 #[inline]
 pub unsafe fn ComDBClaimNextFreePort<'a, Param0: ::windows::core::IntoParam<'a, HCOMDB>>(hcomdb: Param0, comnumber: *mut u32) -> i32 {
     #[cfg(windows)]
@@ -16,6 +21,7 @@ pub unsafe fn ComDBClaimNextFreePort<'a, Param0: ::windows::core::IntoParam<'a,
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
+#[doc = "*Required features: 'Win32_Devices_SerialCommunication', 'Win32_Foundation'*"]
 #[cfg(feature = "Win32_Foundation")]
 #[inline]
 pub unsafe fn ComDBClaimPort<'a, Param0: ::windows::core::IntoParam<'a, HCOMDB>, Param2: ::windows::core::IntoParam<'a, super::super::Foundation::BOOL>>(hcomdb: Param0, comnumber: u32, forceclaim: Param2, forced: *mut super::super::Foundation::BOOL) -> i32 {
@@ -30,6 +36,7 @@ pub unsafe fn ComDBClaimPort<'a, Param0: ::windows::core::IntoParam<'a, HCOMDB>,
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
+#[doc = "*Required features: 'Win32_Devices_SerialCommunication'*"]
 #[inline]
 pub unsafe fn ComDBClose<'a, Param0: ::windows::core::IntoParam<'a, HCOMDB>>(hcomdb: Param0) -> i32 {
     #[cfg(windows)]
@@ -43,6 +50,7 @@ pub unsafe fn ComDBClose<'a, Param0: ::windows::core::IntoParam<'a, HCOMDB>>(hco
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
+#[doc = "*Required features: 'Win32_Devices_SerialCommunication'*"]
 #[inline]
 pub unsafe fn ComDBGetCurrentPortUsage<'a, Param0: ::windows::core::IntoParam<'a, HCOMDB>>(hcomdb: Param0, buffer: *mut u8, buffersize: u32, reporttype: u32, maxportsreported: *mut u32) -> i32 {
     #[cfg(windows)]
@@ -56,6 +64,7 @@ pub unsafe fn ComDBGetCurrentPortUsage<'a, Param0: ::windows::core::IntoParam<'a
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
+#[doc = "*Required features: 'Win32_Devices_SerialCommunication'*"]
 #[inline]
 pub unsafe fn ComDBOpen(phcomdb: *mut isize) -> i32 {
     #[cfg(windows)]
@@ -69,6 +78,7 @@ pub unsafe fn ComDBOpen(phcomdb: *mut isize) -> i32 {
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
+#[doc = "*Required features: 'Win32_Devices_SerialCommunication'*"]
 #[inline]
 pub unsafe fn ComDBReleasePort<'a, Param0: ::windows::core::IntoParam<'a, HCOMDB>>(hcomdb: Param0, comnumber: u32) -> i32 {
     #[cfg(windows)]
@@ -82,6 +92,7 @@ pub unsafe fn ComDBReleasePort<'a, Param0: ::windows::core::IntoParam<'a, HCOMDB
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
+#[doc = "*Required features: 'Win32_Devices_SerialCommunication'*"]
 #[inline]
 pub unsafe fn ComDBResizeDatabase<'a, Param0: ::windows::core::IntoParam<'a, HCOMDB>>(hcomdb: Param0, newsize: u32) -> i32 {
     #[cfg(windows)]
@@ -95,15 +106,37 @@ pub unsafe fn ComDBResizeDatabase<'a, Param0: ::windows::core::IntoParam<'a, HCO
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
-#[derive(:: core :: clone :: Clone, :: core :: marker :: Copy, :: core :: fmt :: Debug, :: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 #[repr(transparent)]
+#[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq)]
 pub struct HCOMDB(pub isize);
+impl HCOMDB {
+    pub fn is_invalid(&self) -> bool {
+        *self == unsafe { ::core::mem::zeroed() }
+    }
+    pub fn ok(self) -> ::windows::core::Result<Self> {
+        if !self.is_invalid() {
+            Ok(self)
+        } else {
+            Err(::windows::core::Error::from_win32())
+        }
+    }
+}
 impl ::core::default::Default for HCOMDB {
     fn default() -> Self {
         unsafe { ::core::mem::zeroed() }
     }
 }
-unsafe impl ::windows::core::Handle for HCOMDB {}
+impl ::core::clone::Clone for HCOMDB {
+    fn clone(&self) -> Self {
+        *self
+    }
+}
+impl ::core::marker::Copy for HCOMDB {}
+impl ::core::fmt::Debug for HCOMDB {
+    fn fmt(&self, f: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
+        f.debug_tuple("HCOMDB").field(&self.0).finish()
+    }
+}
 unsafe impl ::windows::core::Abi for HCOMDB {
     type Abi = Self;
 }
